@@ -2,7 +2,7 @@ import matplotlib.pyplot as plt
 import numpy as np
 from matplotlib.widgets import Slider
 
-from mpl_interactions import interactive_plot_factory
+from mpl_interactions import ipyplot as iplt
 
 fig, ax = plt.subplots()
 plt.subplots_adjust(bottom=0.25)
@@ -15,5 +15,5 @@ def f(x, freq):
 
 axfreq = plt.axes([0.25, 0.1, 0.65, 0.03])
 slider = Slider(axfreq, label="freq", valmin=0.05, valmax=10)
-controls = interactive_plot_factory(ax, f, x=x, freq=slider)
+controls = iplt.plot(x, f, freq=slider, ax=ax)
 plt.show()
